@@ -1,7 +1,9 @@
 from abc import ABC, abstractmethod
 
+from .lazy_value import LazyValue
+
 
 class IEnvironmentManager(ABC):
     @abstractmethod
-    def _get(self, key: str) -> str | None:
+    def get(self, key: str) -> LazyValue:
         raise NotImplementedError
